import { EventEmitter, OnChanges, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { BaseService } from '../../state/base.service';
import { BaseStore } from '../../state/base.store';
import { MetaDataModel } from '../../models/meta-data.model';
import { BaseQuery } from '../../state/base.query';
import { Paginator } from 'primeng/paginator';
import { TableSecondaryModel } from '../models/table-secondary.model';
import * as i0 from "@angular/core";
/**
 * A reusable table component that displays dynamic data using PrimeNG's Table.
 * Supports features like pagination, search, row actions, selection, and routing.
 */
export declare class TableSecondaryComponent implements OnInit, OnChanges, OnDestroy {
    private _router;
    private service;
    private activatedRoute;
    private baseQuery;
    private baseStore;
    table: TableSecondaryModel;
    metaData: MetaDataModel;
    title: string;
    builder: any;
    showStatus: boolean;
    showActions: boolean;
    showSearchBar: boolean;
    showNewRecordButton: boolean;
    showRefreshButton: boolean;
    pathName: string;
    selectionMode: 'single' | 'multiple' | undefined;
    selection: any;
    usePagination: boolean;
    scrollHeight: string;
    selectionChange: EventEmitter<any>;
    rowSelection: any;
    rowSelectionChange: EventEmitter<any>;
    sortChanged: EventEmitter<any>;
    enableSelection: boolean;
    noRecordsMessage: string;
    recordNumber: number;
    page: number;
    limit: number;
    first: number;
    globalFilter: string;
    sortField: string;
    sortOrder: number;
    private destroy$;
    paginator: Paginator;
    onDeleteRow: EventEmitter<any>;
    searchTerm: string;
    filterQuery: string;
    onPage: EventEmitter<any>;
    tableNgClassExpression: string;
    constructor(_router: Router, service: BaseService<any>, activatedRoute: ActivatedRoute, baseQuery: BaseQuery<any>, baseStore: BaseStore<any>);
    /**
     * Lifecycle hook that is called after data-bound properties are initialized.
     * Initializes the record count and validates table headers.
     */
    ngOnInit(): void;
    /**
     * Lifecycle hook called when any data-bound property changes.
     * Resets pagination if page is changed.
     */
    ngOnChanges(): void;
    ngOnDestroy(): void;
    private updateRecordNumber;
    /**
     * Returns the unique key used to identify each row in the table.
     * @returns {string} The data key used for identifying rows, or an empty string if not set.
     */
    get validDataKey(): string;
    /**
     * Clears the global search filter and resets the table.
     * @param {any} table - The PrimeNG table instance.
     */
    clearSearch(table: any): void;
    /**
     * Navigates to the route for creating a new record.
     */
    handleCreate(): void;
    /**
     * Navigates to the edit page for the given record ID.
     * @param {number} id - The ID of the record to edit.
     */
    handleEditClick(id: number): void;
    /**
     * Logs row data intended for editing.
     * @param {any} rowData - The data of the row to edit.
     */
    editRow(rowData: any): void;
    /**
     * Handles the deletion of a row by emitting the row data and preventing event propagation.
     * @param {Event} event - The DOM event triggered by the delete action.
     * @param {any} rowData - The data object of the row to be deleted.
     */
    deleteRow(event: Event, rowData: any): void;
    /**
     * Logs row data intended for viewing.
     * @param {any} rowData - The data of the row to view.
     */
    viewRow(rowData: any): void;
    /**
     * Returns CSS class for a table cell based on its content.
     * @param {any} col - The column definition.
     * @param {any} rowData - The data for the row.
     * @returns {string} A space-separated list of CSS classes for the cell.
     */
    getRowClass(col: any, rowData: any): string;
    /**
     * Handles pagination and data reload on paginator event.
     * @param {object} event - The PrimeNG paginator event.
     * @param {number} event.first - The index of the first record in the current page.
     * @param {number} event.rows - The number of records per page.
     */
    handleLoadRecords(event: any): void;
    /**
     * Emits the updated selection when user changes selection in the table.
     * @param {any} event - The new selection data.
     */
    onSelectionChange(event: any): void;
    /**
     * Emits the selected row when a row is clicked.
     * @param {any} rowData - The data of the clicked row.
     */
    onRowClick(rowData: any): void;
    /**
     * Handles the click event on a table row.
     * If row selection is enabled (`enableSelection` is true),
     * it delegates the event to the `onRowClick` method with the provided row data.
     * @param {any} rowData - The data object for the clicked table row.
     */
    handleRowClick(rowData: any): void;
    /**
     * Checks if a given row is currently selected.
     * @param {any} rowData - The row data to check.
     * @returns {boolean} `true` if the row is selected, else `false`.
     */
    isRowSelected(rowData: any): boolean;
    onSort(event: any): void;
    /**
     * Utility: Check if value is array (for template use)
     */
    isArray(val: any): boolean;
    shouldShowValue(col: any, rowData: any): boolean;
    /**
     * Evaluates ngClass expression for dynamic styling
     * @param {string} expression - The ngClass expression to evaluate
     * @param {any} rowData - The row data to use in evaluation
     * @returns {string} The evaluated CSS classes
     */
    evaluateNgClass(expression: string, rowData: any): string;
    /**
     * Evaluates ngStyle expression for dynamic inline styles
     * @param {string} expression - The ngStyle expression to evaluate
     * @param {any} rowData - The row data to use in evaluation
     * @returns {any} The evaluated style object
     */
    evaluateNgStyle(expression: string, rowData: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableSecondaryComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableSecondaryComponent, "lib-table-secondary", never, { "table": { "alias": "table"; "required": false; }; "metaData": { "alias": "metaData"; "required": false; }; "title": { "alias": "title"; "required": false; }; "builder": { "alias": "builder"; "required": false; }; "showStatus": { "alias": "showStatus"; "required": false; }; "showActions": { "alias": "showActions"; "required": false; }; "showSearchBar": { "alias": "showSearchBar"; "required": false; }; "showNewRecordButton": { "alias": "showNewRecordButton"; "required": false; }; "showRefreshButton": { "alias": "showRefreshButton"; "required": false; }; "pathName": { "alias": "pathName"; "required": false; }; "selectionMode": { "alias": "selectionMode"; "required": false; }; "selection": { "alias": "selection"; "required": false; }; "usePagination": { "alias": "usePagination"; "required": false; }; "scrollHeight": { "alias": "scrollHeight"; "required": false; }; "rowSelection": { "alias": "rowSelection"; "required": false; }; "enableSelection": { "alias": "enableSelection"; "required": false; }; "noRecordsMessage": { "alias": "noRecordsMessage"; "required": false; }; "sortField": { "alias": "sortField"; "required": false; }; "sortOrder": { "alias": "sortOrder"; "required": false; }; "searchTerm": { "alias": "searchTerm"; "required": false; }; "filterQuery": { "alias": "filterQuery"; "required": false; }; }, { "selectionChange": "selectionChange"; "rowSelectionChange": "rowSelectionChange"; "sortChanged": "sortChanged"; "onDeleteRow": "onDeleteRow"; "onPage": "onPage"; }, never, never, true, never>;
}
